//
//  SCAdSlot.h
//  SmartclipSDKiOS
//
//  Copyright © 2019 smartclip. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreGraphics/CoreGraphics.h>
#import "SCAdMacros.h"

NS_ASSUME_NONNULL_BEGIN
@class SCAdVariants;

/**
 * This class is used to specify an AdSlot for the SCAdSequencer
 * which is used for instream playback
 */
@interface SCAdSlot : NSObject
/// Your adTag for this slot
@property (nonatomic, strong)   NSString *adTag;
/// Time when the slot should start (between 0 and 1 - eg.: 0.5 for the middle of the content video)
@property (nonatomic)           CGFloat relativeSlotTime;
/// Specify your ad variants for the slot (opener, closer, bumper)
@property (nonatomic, strong)   SCAdVariants *variants;
/// Specify your skipOffset (in seconds) for this slot -1 means no skipOffet
@property (nonatomic)           NSInteger       skipOffset;
/// Position of the adSlot (preRoll, midRoll, postRoll or standAlone)
@property (nonatomic)           enum SCBreakPosition breakPosition;
///Initializer
- (instancetype)initWithAdTag:(nonnull NSString*)adTag
              relativeSlotTime:(CGFloat)relativeTime
                      variants:(nullable SCAdVariants*)variants
                    skipOffset:(NSInteger)skipOffset
                 breakPosition:(SCBreakPosition)breakPosition;
@end

NS_ASSUME_NONNULL_END
